@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies).
+** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
 ** Contact: http://www.qt-project.org/legal
 **
 ** This file is part of Qt Creator.
@@ -26,15 +26,18 @@
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
 ****************************************************************************/
+
 #include "CppRewriter.h"
-#include <TypeVisitor.h>
-#include <NameVisitor.h>
-#include <CoreTypes.h>
-#include <Symbols.h>
-#include <Literals.h>
-#include <Names.h>
-#include <Scope.h>
-#include <Overview.h>
+
+#include "Overview.h"
+
+#include <cplusplus/TypeVisitor.h>
+#include <cplusplus/NameVisitor.h>
+#include <cplusplus/CoreTypes.h>
+#include <cplusplus/Symbols.h>
+#include <cplusplus/Literals.h>
+#include <cplusplus/Names.h>
+#include <cplusplus/Scope.h>
 
 #include <QVarLengthArray>
 #include <QRegExp>
@@ -145,7 +148,7 @@ public:
 
             funTy->setReturnType(rewrite->rewriteType(type->returnType()));
 
-            for (unsigned i = 0; i < type->argumentCount(); ++i) {
+            for (unsigned i = 0, argc = type->argumentCount(); i < argc; ++i) {
                 Symbol *arg = type->argumentAt(i);
 
                 Argument *newArg = control()->newArgument(0, 0);
@@ -263,7 +266,8 @@ public:
             QVarLengthArray<FullySpecifiedType, 8> args(name->templateArgumentCount());
             for (unsigned i = 0; i < name->templateArgumentCount(); ++i)
                 args[i] = rewrite->rewriteType(name->templateArgumentAt(i));
-            temps.append(control()->templateNameId(identifier(name->identifier()), args.data(), args.size()));
+            temps.append(control()->templateNameId(identifier(name->identifier()), name->isSpecialization(),
+                                                   args.data(), args.size()));
         }
 
         virtual void visit(const DestructorNameId *name)
@@ -406,9 +410,8 @@ FullySpecifiedType UseMinimalNames::apply(const Name *name, Rewrite *rewrite) co
 
     const QList<LookupItem> results = context.lookup(name, scope);
     foreach (const LookupItem &r, results) {
-        if (Symbol *d = r.declaration()) {
+        if (Symbol *d = r.declaration())
             return control->namedType(LookupContext::minimalName(d, _target, control));
-        }
 
         return r.type();
     }
@@ -451,7 +454,7 @@ const Name *rewriteName(const Name *name,
 
 static QString chopConst(QString type)
 {
-   while (1) {
+    while (1) {
         if (type.startsWith(QLatin1String("const")))
             type = type.mid(5);
         else if (type.startsWith(QLatin1Char(' ')))
@@ -512,22 +515,31 @@ static inline QString fixNestedTemplates(QString s)
             && s.at(size - 1) == QLatin1Char('>')
             && s.at(size - 2) == QLatin1Char(' ')
             && s.at(size - 3) != QLatin1Char('>'))
-            s.remove(size - 2, 1);
+        s.remove(size - 2, 1);
     return s;
 }
 
 CPLUSPLUS_EXPORT QString simplifySTLType(const QString &typeIn)
 {
     QString type = typeIn;
-    if (type.startsWith("class ")) // MSVC prepends class,struct
+    if (type.startsWith(QLatin1String("class "))) // MSVC prepends class,struct
         type.remove(0, 6);
-    if (type.startsWith("struct "))
+    if (type.startsWith(QLatin1String("struct ")))
         type.remove(0, 7);
 
+    type.replace(QLatin1String("std::__1::"), QLatin1String("std::"));
     type.replace(QLatin1Char('*'), QLatin1Char('@'));
 
     for (int i = 0; i < 10; ++i) {
-        int start = type.indexOf("std::allocator<");
+        // std::ifstream
+        QRegExp ifstreamRE(QLatin1String("std::basic_ifstream<char,\\s*std::char_traits<char>\\s*>"));
+        ifstreamRE.setMinimal(true);
+        QTC_ASSERT(ifstreamRE.isValid(), return typeIn);
+        if (ifstreamRE.indexIn(type) != -1)
+            type.replace(ifstreamRE.cap(0), QLatin1String("std::ifstream"));
+
+        // Anything with a std::allocator
+        int start = type.indexOf(QLatin1String("std::allocator<"));
         if (start == -1)
             break;
         // search for matching '>'
@@ -575,7 +587,7 @@ CPLUSPLUS_EXPORT QString simplifySTLType(const QString &typeIn)
             type.replace(setRE.cap(0), QString::fromLatin1("set<%1>").arg(inner));
 
         // std::map
-        if (inner.startsWith("std::pair<")) {
+        if (inner.startsWith(QLatin1String("std::pair<"))) {
             // search for outermost ',', split key and value
             int pos;
             int level = 0;
@@ -595,19 +607,18 @@ CPLUSPLUS_EXPORT QString simplifySTLType(const QString &typeIn)
                 pos++;
             const QString value = inner.mid(pos, inner.size() - pos - 1).trimmed();
             const QString valueEsc = QRegExp::escape(value);
-            QRegExp mapRE1(QString("map<%1, ?%2, ?std::less<%3 ?>, ?%4\\s*>")
-                .arg(keyEsc, valueEsc, keyEsc, allocEsc));
+            QRegExp mapRE1(QString::fromLatin1("map<%1, ?%2, ?std::less<%3 ?>, ?%4\\s*>")
+                           .arg(keyEsc, valueEsc, keyEsc, allocEsc));
             mapRE1.setMinimal(true);
             QTC_ASSERT(mapRE1.isValid(), return typeIn);
             if (mapRE1.indexIn(type) != -1) {
-                type.replace(mapRE1.cap(0), QString("map<%1, %2>").arg(key, value));
+                type.replace(mapRE1.cap(0), QString::fromLatin1("map<%1, %2>").arg(key, value));
             } else {
-                QRegExp mapRE2(QString("map<const %1, ?%2, ?std::less<const %3>, ?%4\\s*>")
-                    .arg(keyEsc, valueEsc, keyEsc, allocEsc));
+                QRegExp mapRE2(QString::fromLatin1("map<const %1, ?%2, ?std::less<const %3>, ?%4\\s*>")
+                               .arg(keyEsc, valueEsc, keyEsc, allocEsc));
                 mapRE2.setMinimal(true);
-                if (mapRE2.indexIn(type) != -1) {
-                    type.replace(mapRE2.cap(0), QString("map<const %1, %2>").arg(key, value));
-                }
+                if (mapRE2.indexIn(type) != -1)
+                    type.replace(mapRE2.cap(0), QString::fromLatin1("map<const %1, %2>").arg(key, value));
             }
         }
     }
