@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies).
+** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
 ** Contact: http://www.qt-project.org/legal
 **
 ** This file is part of Qt Creator.
@@ -28,17 +28,18 @@
 ****************************************************************************/
 
 #include "contextpanewidget.h"
+
+#include <utils/hostosinfo.h>
+
 #include <QToolButton>
 #include <QFontComboBox>
 #include <QComboBox>
 #include <QSpinBox>
-#include <QToolButton>
 #include <QHBoxLayout>
 #include <QVBoxLayout>
 #include <QLabel>
 #include <QMouseEvent>
 #include <QGridLayout>
-#include <QToolButton>
 #include <QGraphicsEffect>
 #include <QAction>
 #include "contextpanetextwidget.h"
@@ -48,6 +49,8 @@
 #include "customcolordialog.h"
 #include "colorbutton.h"
 
+using namespace Utils;
+
 namespace QmlEditorWidgets {
 
 /* XPM */
@@ -101,12 +104,12 @@ DragWidget::DragWidget(QWidget *parent) : QFrame(parent)
 
     // TODO: The following code should be enabled for OSX
     // when QTBUG-23205 is fixed
-#ifndef Q_OS_MAC
-    m_dropShadowEffect = new QGraphicsDropShadowEffect;
-    m_dropShadowEffect->setBlurRadius(6);
-    m_dropShadowEffect->setOffset(2, 2);
-    setGraphicsEffect(m_dropShadowEffect);
-#endif
+    if (!HostOsInfo::isMacHost()) {
+        m_dropShadowEffect = new QGraphicsDropShadowEffect;
+        m_dropShadowEffect->setBlurRadius(6);
+        m_dropShadowEffect->setOffset(2, 2);
+        setGraphicsEffect(m_dropShadowEffect);
+    }
 }
 
 void DragWidget::mousePressEvent(QMouseEvent * event)
@@ -126,12 +129,12 @@ void DragWidget::mouseReleaseEvent(QMouseEvent *event)
         m_startPos = QPoint(-1, -1);
         // TODO: The following code should be enabled for OSX
         // when QTBUG-23205 is fixed
-#ifndef Q_OS_MAC
-        m_dropShadowEffect = new QGraphicsDropShadowEffect;
-        m_dropShadowEffect->setBlurRadius(6);
-        m_dropShadowEffect->setOffset(2, 2);
-        setGraphicsEffect(m_dropShadowEffect);
-#endif
+        if (!HostOsInfo::isMacHost()) {
+            m_dropShadowEffect = new QGraphicsDropShadowEffect;
+            m_dropShadowEffect->setBlurRadius(6);
+            m_dropShadowEffect->setOffset(2, 2);
+            setGraphicsEffect(m_dropShadowEffect);
+        }
     }
     QFrame::mouseReleaseEvent(event);
 }
@@ -176,16 +179,14 @@ void DragWidget::protectedMoved()
 
 void DragWidget::leaveEvent(QEvent *)
 {
-#ifdef Q_OS_MAC
-    unsetCursor();
-#endif
+    if (HostOsInfo::isMacHost())
+        unsetCursor();
 }
 
 void DragWidget::enterEvent(QEvent *)
 {
-#ifdef Q_OS_MAC
-    setCursor(Qt::ArrowCursor);
-#endif
+    if (HostOsInfo::isMacHost())
+        setCursor(Qt::ArrowCursor);
 }
 
 ContextPaneWidget::ContextPaneWidget(QWidget *parent) : DragWidget(parent), m_currentWidget(0)
@@ -231,9 +232,8 @@ ContextPaneWidget::ContextPaneWidget(QWidget *parent) : DragWidget(parent), m_cu
     m_disableAction->setCheckable(true);
     connect(m_disableAction.data(), SIGNAL(toggled(bool)), this, SLOT(onDisable(bool)));
     m_pinned = false;
-#ifdef Q_OS_MAC
-    setCursor(Qt::ArrowCursor);
-#endif
+    if (HostOsInfo::isMacHost())
+        setCursor(Qt::ArrowCursor);
 }
 
 ContextPaneWidget::~ContextPaneWidget()
@@ -241,7 +241,7 @@ ContextPaneWidget::~ContextPaneWidget()
     //if the pane was never activated the widget is not in a widget tree
     if (!m_bauhausColorDialog.isNull())
         delete m_bauhausColorDialog.data();
-        m_bauhausColorDialog.clear();
+        m_bauhausColorDialog = 0;
 }
 
 void ContextPaneWidget::activate(const QPoint &pos, const QPoint &alternative, const QPoint &alternative2, bool pinned)
@@ -341,17 +341,17 @@ bool ContextPaneWidget::setType(const QStringList &types)
     m_rectangleWidget->hide();
     m_easingWidget->hide();
 
-    if (types.contains("Text") ||
-        types.contains("TextEdit") ||
-        types.contains("TextInput")) {
+    if (types.contains(QLatin1String("Text")) ||
+        types.contains(QLatin1String("TextEdit")) ||
+        types.contains(QLatin1String("TextInput"))) {
         m_currentWidget = m_textWidget;
         m_textWidget->show();
         m_textWidget->setStyleVisible(true);
         m_textWidget->setVerticalAlignmentVisible(true);
-        if (types.contains("TextInput")) {
+        if (types.contains(QLatin1String("TextInput"))) {
             m_textWidget->setVerticalAlignmentVisible(false);
             m_textWidget->setStyleVisible(false);
-        } else if (types.contains("TextEdit")) {
+        } else if (types.contains(QLatin1String("TextEdit"))) {
             m_textWidget->setStyleVisible(false);
         }
         resize(sizeHint());
@@ -364,7 +364,7 @@ bool ContextPaneWidget::setType(const QStringList &types)
         resize(sizeHint());
         return true;
     }
-    if (types.contains("Rectangle")) {
+    if (types.contains(QLatin1String("Rectangle"))) {
         m_currentWidget = m_rectangleWidget;
         m_rectangleWidget->enabableGradientEditing(!isPropertyChanges());
         m_rectangleWidget->show();
@@ -372,14 +372,14 @@ bool ContextPaneWidget::setType(const QStringList &types)
         return true;
     }
 
-    if (types.contains("BorderImage")) {
+    if (types.contains(QLatin1String("BorderImage"))) {
         m_currentWidget = m_borderImageWidget;
         m_borderImageWidget->show();
         resize(sizeHint());
         return true;
     }
 
-    if (types.contains("Image")) {
+    if (types.contains(QLatin1String("Image"))) {
         m_currentWidget = m_imageWidget;
         m_imageWidget->show();
         resize(sizeHint());
@@ -390,8 +390,10 @@ bool ContextPaneWidget::setType(const QStringList &types)
 
 bool ContextPaneWidget::acceptsType(const QStringList &types)
 {
-    return types.contains("Text") || types.contains("TextEdit") || types.contains("TextInput") || m_easingWidget->acceptsType(types) ||
-            types.contains("Rectangle") || types.contains("Image") || types.contains("BorderImage");
+    return types.contains(QLatin1String("Text")) || types.contains(QLatin1String("TextEdit")) ||
+            types.contains(QLatin1String("TextInput")) || m_easingWidget->acceptsType(types) ||
+            types.contains(QLatin1String("Rectangle")) || types.contains(QLatin1String("Image")) ||
+            types.contains(QLatin1String("BorderImage"));
 }
 
 void ContextPaneWidget::onTogglePane()
@@ -409,7 +411,7 @@ void ContextPaneWidget::onTogglePane()
 }
 
 void ContextPaneWidget::onShowColorDialog(bool checked, const QPoint &p)
-{    
+{
     if (checked) {
         colorDialog()->setParent(parentWidget());
         colorDialog()->move(p);
@@ -421,7 +423,7 @@ void ContextPaneWidget::onShowColorDialog(bool checked, const QPoint &p)
 }
 
 void ContextPaneWidget::onDisable(bool b)
-{       
+{
     enabledChanged(b);
     if (!b) {
         hide();
@@ -446,7 +448,7 @@ void ContextPaneWidget::protectedMoved()
 }
 
 QWidget* ContextPaneWidget::createFontWidget()
-{    
+{
     m_textWidget = new ContextPaneTextWidget(this);
     connect(m_textWidget, SIGNAL(propertyChanged(QString,QVariant)), this, SIGNAL(propertyChanged(QString,QVariant)));
     connect(m_textWidget, SIGNAL(removeProperty(QString)), this, SIGNAL(removeProperty(QString)));
