@@ -32,17 +32,13 @@
 #include "coreconstants.h"
 #include "findplaceholder.h"
 
-#include "coreconstants.h"
 #include "icore.h"
 #include "ioutputpane.h"
-#include "mainwindow.h"
 #include "modemanager.h"
 
 #include <coreplugin/actionmanager/actionmanager.h>
 #include <coreplugin/actionmanager/actioncontainer.h>
-#include <coreplugin/actionmanager/command.h>
 #include <coreplugin/editormanager/editormanager.h>
-#include <coreplugin/findplaceholder.h>
 #include <coreplugin/editormanager/ieditor.h>
 
 #include <extensionsystem/pluginmanager.h>
@@ -61,12 +57,10 @@
 #include <QLabel>
 #include <QMenu>
 #include <QPainter>
-#include <QSplitter>
 #include <QStyle>
 #include <QStackedWidget>
 #include <QToolButton>
 #include <QTimeLine>
-#include <QLabel>
 
 namespace Core {
 namespace Internal {
@@ -248,6 +242,7 @@ void OutputPaneManager::init()
     const int n = m_panes.size();
 
     int shortcutNumber = 1;
+    const Id baseId = Id("QtCreator.Pane.");
     for (int i = 0; i != n; ++i) {
         IOutputPane *outPane = m_panes.at(i);
         const int idx = m_outputWidgetPane->addWidget(outPane->outputWidget(this));
@@ -273,14 +268,14 @@ void OutputPaneManager::init()
 
         minTitleWidth = qMax(minTitleWidth, titleFm.width(outPane->displayName()));
 
-        QString actionId = QLatin1String("QtCreator.Pane.") + outPane->displayName().simplified();
-        actionId.remove(QLatin1Char(' '));
-        Id id = Id::fromString(actionId);
+        QString suffix = outPane->displayName().simplified();
+        suffix.remove(QLatin1Char(' '));
+        const Id id = baseId.withSuffix(suffix);
         QAction *action = new QAction(outPane->displayName(), this);
         Command *cmd = ActionManager::registerAction(action, id, globalContext);
 
         mpanes->addAction(cmd, "Coreplugin.OutputPane.PanesGroup");
-        m_actions.append(cmd->action());
+        m_actions.append(action);
         m_ids.append(id);
 
         cmd->setDefaultKeySequence(QKeySequence(paneShortCut(shortcutNumber)));
@@ -294,7 +289,7 @@ void OutputPaneManager::init()
         bool visible = outPane->priorityInStatusBar() != -1;
         button->setVisible(visible);
 
-        connect(cmd->action(), SIGNAL(triggered()), this, SLOT(shortcutTriggered()));
+        connect(action, SIGNAL(triggered()), this, SLOT(shortcutTriggered()));
     }
 
     m_titleLabel->setMinimumWidth(minTitleWidth + m_titleLabel->contentsMargins().left()
@@ -317,10 +312,12 @@ void OutputPaneManager::shortcutTriggered()
     // then just give it focus.
     int current = currentIndex();
     if (OutputPanePlaceHolder::isCurrentVisible() && current == idx) {
-        if (!outputPane->hasFocus() && outputPane->canFocus())
+        if (!outputPane->hasFocus() && outputPane->canFocus()) {
             outputPane->setFocus();
-        else
+            ICore::raiseWindow(m_outputWidgetPane);
+        } else {
             slotHide();
+        }
     } else {
         // Else do the same as clicking on the button does.
         buttonTriggered(idx);
@@ -481,8 +478,10 @@ void OutputPaneManager::showPage(int idx, int flags)
         ensurePageVisible(idx);
         IOutputPane *out = m_panes.at(idx);
         out->visibilityChanged(true);
-        if (flags & IOutputPane::WithFocus && out->canFocus())
+        if (flags & IOutputPane::WithFocus && out->canFocus()) {
             out->setFocus();
+            ICore::raiseWindow(m_outputWidgetPane);
+        }
 
         if (flags & IOutputPane::EnsureSizeHint)
             ph->ensureSizeHintAsMinimum();
@@ -593,16 +592,16 @@ int OutputPaneManager::currentIndex() const
 
 static QString buttonStyleSheet()
 {
-    return QLatin1String("QToolButton { border-image: url(:/core/images/panel_button.png) 2 2 2 19;"
-                         " border-width: 2px 2px 2px 19px; padding-left: -17; padding-right: 4 } "
+    QString styleSheet = QLatin1String("QToolButton { border-image: url(:/core/images/panel_button.png) 2 2 2 19;"
+            " border-width: 2px 2px 2px 19px; padding-left: -17; padding-right: 4 } "
             "QToolButton:checked { border-image: url(:/core/images/panel_button_checked.png) 2 2 2 19 } "
-            "QToolButton::menu-indicator { width:0; height:0 }"
-#ifndef Q_OS_MAC // Mac UIs usually don't hover
-            "QToolButton:checked:hover { border-image: url(:/core/images/panel_button_checked_hover.png) 2 2 2 19 } "
-            "QToolButton:pressed:hover { border-image: url(:/core/images/panel_button_pressed.png) 2 2 2 19 } "
-            "QToolButton:hover { border-image: url(:/core/images/panel_button_hover.png) 2 2 2 19 } "
-#endif
-            );
+            "QToolButton::menu-indicator { width:0; height:0 }");
+    if (!Utils::HostOsInfo::isMacHost()) { // Mac UIs usually don't hover
+        styleSheet += QLatin1String("QToolButton:checked:hover { border-image: url(:/core/images/panel_button_checked_hover.png) 2 2 2 19 } "
+                "QToolButton:pressed:hover { border-image: url(:/core/images/panel_button_pressed.png) 2 2 2 19 } "
+                "QToolButton:hover { border-image: url(:/core/images/panel_button_hover.png) 2 2 2 19 } ");
+    }
+    return styleSheet;
 }
 
 OutputPaneToggleButton::OutputPaneToggleButton(int number, const QString &text,
