@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies).
+** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
 ** Contact: http://www.qt-project.org/legal
 **
 ** This file is part of Qt Creator.
@@ -92,10 +92,11 @@ Protocol::ContentType Protocol::contentType(const QString &mt)
         return C;
     if (mt == QLatin1String(CppTools::Constants::CPP_SOURCE_MIMETYPE)
         || mt == QLatin1String(CppTools::Constants::CPP_HEADER_MIMETYPE)
-        || mt == QLatin1String(CppTools::Constants::OBJECTIVE_CPP_SOURCE_MIMETYPE)
         || mt == QLatin1String(CppTools::Constants::OBJECTIVE_CPP_SOURCE_MIMETYPE))
         return Cpp;
     if (mt == QLatin1String(QmlJSTools::Constants::QML_MIMETYPE)
+        || mt == QLatin1String(QmlJSTools::Constants::QMLPROJECT_MIMETYPE)
+        || mt == QLatin1String(QmlJSTools::Constants::QBS_MIMETYPE)
         || mt == QLatin1String(QmlJSTools::Constants::JS_MIMETYPE)
         || mt == QLatin1String(QmlJSTools::Constants::JSON_MIMETYPE))
         return JavaScript;
@@ -169,50 +170,27 @@ bool Protocol::showConfigurationError(const Protocol *p,
     bool rc = false;
     if (mb.clickedButton() == settingsButton)
         rc = Core::ICore::showOptionsDialog(p->settingsPage()->category(),
-                                                        p->settingsPage()->id(),
-                                                        parent);
+                                            p->settingsPage()->id(), parent);
     return rc;
 }
 
+// --------- NetworkProtocol
 
-// ------------ NetworkAccessManagerProxy
-NetworkAccessManagerProxy::NetworkAccessManagerProxy()
-{
-}
-
-NetworkAccessManagerProxy::~NetworkAccessManagerProxy()
-{
-}
-
-QNetworkReply *NetworkAccessManagerProxy::httpGet(const QString &link)
+QNetworkReply *NetworkProtocol::httpGet(const QString &link)
 {
     QUrl url(link);
     QNetworkRequest r(url);
-    return networkAccessManager()->get(r);
+    return Utils::NetworkAccessManager::instance()->get(r);
 }
 
-QNetworkReply *NetworkAccessManagerProxy::httpPost(const QString &link, const QByteArray &data)
+QNetworkReply *NetworkProtocol::httpPost(const QString &link, const QByteArray &data)
 {
     QUrl url(link);
     QNetworkRequest r(url);
     // Required for Qt 4.8
     r.setHeader(QNetworkRequest::ContentTypeHeader,
                 QVariant(QByteArray("application/x-www-form-urlencoded")));
-    return networkAccessManager()->post(r, data);
-}
-
-QNetworkAccessManager *NetworkAccessManagerProxy::networkAccessManager()
-{
-    if (m_networkAccessManager.isNull())
-        m_networkAccessManager.reset(new Utils::NetworkAccessManager);
-    return m_networkAccessManager.data();
-}
-
-// --------- NetworkProtocol
-
-NetworkProtocol::NetworkProtocol(const NetworkAccessManagerProxyPtr &nw) :
-    m_networkAccessManager(nw)
-{
+    return Utils::NetworkAccessManager::instance()->post(r, data);
 }
 
 NetworkProtocol::~NetworkProtocol()
