@@ -32,18 +32,9 @@
 
 #include "cpptools_global.h"
 
-#include <extensionsystem/iplugin.h>
 #include <projectexplorer/projectexplorer.h>
-#include <find/ifindfilter.h>
-#include <utils/filesearch.h>
 
-#include <QTextDocument>
-#include <QKeySequence>
 #include <QSharedPointer>
-#include <QFutureInterface>
-#include <QPointer>
-#include <QFutureWatcher>
-#include <QHash>
 
 QT_BEGIN_NAMESPACE
 class QFileInfo;
@@ -59,7 +50,7 @@ namespace Internal {
 class CppModelManager;
 struct CppFileSettings;
 
-class CppToolsPlugin : public ExtensionSystem::IPlugin
+class CPPTOOLS_EXPORT CppToolsPlugin : public ExtensionSystem::IPlugin
 {
     Q_OBJECT
     Q_PLUGIN_METADATA(IID "org.qt-project.Qt.QtCreatorPlugin" FILE "CppTools.json")
@@ -68,14 +59,17 @@ public:
     CppToolsPlugin();
     ~CppToolsPlugin();
 
+    static CppToolsPlugin *instance();
+
     bool initialize(const QStringList &arguments, QString *errorMessage);
     void extensionsInitialized();
     ShutdownFlag aboutToShutdown();
 
-private slots:
+public slots:
     void switchHeaderSource();
     void switchHeaderSourceInNextSplit();
 
+private slots:
 #ifdef WITH_TESTS
     void test_codegen_public_in_empty_class();
     void test_codegen_public_in_nonempty_class();
@@ -88,6 +82,8 @@ private slots:
     void test_codegen_definition_first_member();
     void test_codegen_definition_last_member();
     void test_codegen_definition_middle_member();
+    void test_codegen_definition_middle_member_surrounded_by_undefined();
+    void test_codegen_definition_member_specific_file();
 
     void test_completion_forward_declarations_present();
     void test_completion_inside_parentheses_c_style_conversion();
@@ -110,6 +106,8 @@ private slots:
     void test_completion_base_class_has_name_the_same_as_derived_data();
     void test_completion_cyclic_inheritance();
     void test_completion_cyclic_inheritance_data();
+    void test_completion_template_function();
+    void test_completion_template_function_data();
     void test_completion_enclosing_template_class();
     void test_completion_enclosing_template_class_data();
     void test_completion_instantiate_nested_class_when_enclosing_is_template();
@@ -117,8 +115,17 @@ private slots:
     void test_completion_instantiate_template_with_default_argument_type();
     void test_completion_instantiate_template_with_default_argument_type_as_template();
     void test_completion_member_access_operator_1();
-    void test_completion_typedef_of_type_and_replace_access_operator();
-    void test_completion_typedef_of_pointer_of_type_and_replace_access_operator();
+
+    void test_completion_typedef_of_type_and_decl_of_type_no_replace_access_operator();
+    void test_completion_typedef_of_pointer_and_decl_of_pointer_no_replace_access_operator();
+    void test_completion_typedef_of_type_and_decl_of_pointer_replace_access_operator();
+    void test_completion_typedef_of_pointer_and_decl_of_type_replace_access_operator();
+
+    void test_completion_predecl_typedef_of_type_and_decl_of_pointer_replace_access_operator();
+    void test_completion_predecl_typedef_of_type_and_decl_type_no_replace_access_operator();
+    void test_completion_predecl_typedef_of_pointer_and_decl_of_pointer_no_replace_access_operator();
+    void test_completion_predecl_typedef_of_pointer_and_decl_of_type_replace_access_operator();
+
     void test_completion_typedef_of_pointer();
     void test_completion_typedef_of_pointer_inside_function();
     void test_completion_typedef_is_inside_function_before_declaration_block();
@@ -126,6 +133,20 @@ private slots:
     void test_completion_template_specialization_with_pointer();
     void test_completion_typedef_using_templates1();
     void test_completion_typedef_using_templates2();
+    void test_completion_namespace_alias_with_many_namespace_declarations();
+    void test_completion_QTCREATORBUG9098();
+    void test_completion_type_and_using_declaration();
+    void test_completion_type_and_using_declaration_data();
+    void test_completion_instantiate_template_with_anonymous_class();
+    void test_completion_instantiate_template_function();
+    void test_completion_crash_cloning_template_class_QTCREATORBUG9329();
+    void test_completion_recursive_auto_declarations1_QTCREATORBUG9503();
+    void test_completion_recursive_auto_declarations2_QTCREATORBUG9503();
+    void test_completion_recursive_typedefs_declarations1();
+    void test_completion_recursive_typedefs_declarations2();
+    void test_completion_recursive_using_declarations1();
+    void test_completion_recursive_using_declarations2();
+    void test_completion_recursive_using_typedef_declarations();
 
     void test_format_pointerdeclaration_in_simpledeclarations();
     void test_format_pointerdeclaration_in_simpledeclarations_data();
@@ -140,6 +161,10 @@ private slots:
 
     void test_modelmanager_paths();
     void test_modelmanager_framework_headers();
+    void test_modelmanager_refresh_1();
+    void test_modelmanager_refresh_2();
+    void test_modelmanager_snapshot_after_two_projects();
+    void test_modelmanager_extraeditorsupport_uiFiles();
 
 private:
     void test_completion();
