@@ -28,24 +28,24 @@
 ****************************************************************************/
 
 #include "breakhandler.h"
-#include "debuggerinternalconstants.h"
 #include "breakpointmarker.h"
 
 #include "debuggeractions.h"
 #include "debuggercore.h"
 #include "debuggerengine.h"
 #include "debuggerstringutils.h"
-#include "stackframe.h"
 
+#include <extensionsystem/invoker.h>
+#include <utils/hostosinfo.h>
 #include <utils/qtcassert.h>
 
 #if USE_BREAK_MODEL_TEST
 #include "modeltest.h"
 #endif
 
-#include <QDir>
-#include <QFileInfo>
 #include <QTimerEvent>
+#include <QDir>
+#include <QDebug>
 
 #define BREAK_ASSERT(cond, action) if (cond) {} else { action; }
 //#define BREAK_ASSERT(cond, action) QTC_ASSERT(cond, action)
@@ -123,7 +123,8 @@ static QString typeToString(BreakpointType type)
             return BreakHandler::tr("Breakpoint on QML Signal Emit");
         case BreakpointAtJavaScriptThrow:
             return BreakHandler::tr("Breakpoint at JavaScript throw");
-        case UnknownType:
+        case UnknownBreakpointType:
+        case LastBreakpointType:
             break;
     }
     return BreakHandler::tr("Unknown Breakpoint Type");
@@ -180,18 +181,16 @@ QIcon BreakHandler::emptyIcon()
 
 static inline bool fileNameMatch(const QString &f1, const QString &f2)
 {
-#ifdef Q_OS_WIN
-    return f1.compare(f2, Qt::CaseInsensitive) == 0;
-#else
+    if (Utils::HostOsInfo::isWindowsHost())
+        return f1.compare(f2, Qt::CaseInsensitive) == 0;
     return f1 == f2;
-#endif
 }
 
 static bool isSimilarTo(const BreakpointParameters &data, const BreakpointResponse &needle)
 {
     // Clear hit.
     // Clear miss.
-    if (needle.type != UnknownType && data.type != UnknownType
+    if (needle.type != UnknownBreakpointType && data.type != UnknownBreakpointType
             && data.type != needle.type)
         return false;
 
@@ -384,7 +383,7 @@ void BreakHandler::loadBreakpoints()
         if (v.isValid())
             data.tracepoint = bool(v.toInt());
         v = map.value(_("type"));
-        if (v.isValid() && v.toInt() != UnknownType)
+        if (v.isValid() && v.toInt() != UnknownBreakpointType)
             data.type = BreakpointType(v.toInt());
         v = map.value(_("module"));
         if (v.isValid())
@@ -398,11 +397,10 @@ void BreakHandler::loadBreakpoints()
         v = map.value(_("message"));
         if (v.isValid())
             data.message = v.toString();
-        if (data.isValid()) {
+        if (data.isValid())
             appendBreakpoint(data);
-        } else {
+        else
             qWarning("Not restoring invalid breakpoint: %s", qPrintable(data.toString()));
-        }
     }
     //qDebug() << "LOADED BREAKPOINTS" << this << list.size();
 }
@@ -1163,18 +1161,13 @@ void BreakHandler::saveSessionData()
 
 void BreakHandler::loadSessionData()
 {
-    m_storage.clear();
-    reset();
-    loadBreakpoints();
-}
-
-void BreakHandler::removeSessionData()
-{
+    beginResetModel();
     Iterator it = m_storage.begin(), et = m_storage.end();
     for ( ; it != et; ++it)
         it->destroyMarker();
     m_storage.clear();
-    reset();
+    endResetModel();
+    loadBreakpoints();
 }
 
 void BreakHandler::breakByFunction(const QString &functionName)
@@ -1257,6 +1250,25 @@ void BreakHandler::updateLineNumberFromMarker(BreakpointModelId id, int lineNumb
     emit layoutChanged();
 }
 
+void BreakHandler::changeLineNumberFromMarker(BreakpointModelId id, int lineNumber)
+{
+    // We need to delay this as it is called from a marker which will be destroyed.
+    ExtensionSystem::InvokerBase invoker;
+    invoker.addArgument(id);
+    invoker.addArgument(lineNumber);
+    invoker.setConnectionType(Qt::QueuedConnection);
+    invoker.invoke(this, "changeLineNumberFromMarkerHelper");
+    QTC_CHECK(invoker.wasSuccessful());
+}
+
+void BreakHandler::changeLineNumberFromMarkerHelper(BreakpointModelId id, int lineNumber)
+{
+    BreakpointParameters data = breakpointData(id);
+    data.lineNumber = lineNumber;
+    removeBreakpoint(id);
+    appendBreakpoint(data);
+}
+
 BreakpointModelIds BreakHandler::allBreakpointIds() const
 {
     BreakpointModelIds ids;
@@ -1419,8 +1431,13 @@ bool BreakHandler::BreakpointItem::needsChange() const
         return true;
     if (data.command != response.command)
         return true;
-    if (data.lineNumber != response.lineNumber)
+    if (data.type == BreakpointByFileAndLine && data.lineNumber != response.lineNumber)
         return true;
+    // FIXME: Too strict, functions may have parameter lists, or not.
+    // if (data.type == BreakpointByFunction && data.functionName != response.functionName)
+    //     return true;
+    // if (data.type == BreakpointByAddress && data.address != response.address)
+    //     return true;
     return false;
 }
 
