@@ -40,15 +40,11 @@
 #include <coreplugin/coreconstants.h>
 #include <coreplugin/actionmanager/actionmanager.h>
 #include <coreplugin/actionmanager/actioncontainer.h>
-#include <coreplugin/actionmanager/command.h>
-#include <coreplugin/editormanager/editormanager.h>
-#include <coreplugin/id.h>
+#include <utils/hostosinfo.h>
 #include <utils/qtcassert.h>
 
-#include <QSet>
 #include <QDebug>
 #include <QAction>
-#include <QTextCursor>
 
 using namespace TextEditor;
 using namespace TextEditor::Internal;
@@ -103,7 +99,9 @@ TextEditorActionHandler::TextEditorActionHandler(const char *context,
     m_indentAction(0),
     m_unindentAction(0),
     m_followSymbolAction(0),
+    m_followSymbolInNextSplitAction(0),
     m_jumpToFileAction(0),
+    m_jumpToFileInNextSplitAction(0),
     m_optionalActions(optionalActions),
     m_currentEditor(0),
     m_contextId(context),
@@ -389,11 +387,25 @@ void TextEditorActionHandler::createActions()
     command->setDefaultKeySequence(QKeySequence(Qt::Key_F2));
     connect(m_followSymbolAction, SIGNAL(triggered()), this, SLOT(openLinkUnderCursor()));
 
+    m_followSymbolInNextSplitAction = new QAction(tr("Follow Symbol Under Cursor in Next Split"), this);
+    command = Core::ActionManager::registerAction(m_followSymbolInNextSplitAction, Constants::FOLLOW_SYMBOL_UNDER_CURSOR_IN_NEXT_SPLIT, m_contextId, true);
+    command->setDefaultKeySequence(QKeySequence(Utils::HostOsInfo::isMacHost()
+                                                ? tr("Meta+E, F2")
+                                                : tr("Ctrl+E, F2")));
+    connect(m_followSymbolInNextSplitAction, SIGNAL(triggered()), this, SLOT(openLinkUnderCursorInNextSplit()));
+
     m_jumpToFileAction = new QAction(tr("Jump To File Under Cursor"), this);
     command = Core::ActionManager::registerAction(m_jumpToFileAction, Constants::JUMP_TO_FILE_UNDER_CURSOR, m_contextId, true);
     command->setDefaultKeySequence(QKeySequence(Qt::Key_F2));
     connect(m_jumpToFileAction, SIGNAL(triggered()), this, SLOT(openLinkUnderCursor()));
 
+    m_jumpToFileInNextSplitAction = new QAction(tr("Jump to File Under Cursor in Next Split"), this);
+    command = Core::ActionManager::registerAction(m_jumpToFileInNextSplitAction, Constants::JUMP_TO_FILE_UNDER_CURSOR_IN_NEXT_SPLIT, m_contextId, true);
+    command->setDefaultKeySequence(QKeySequence(Utils::HostOsInfo::isMacHost()
+                                                ? tr("Meta+E, F2")
+                                                : tr("Ctrl+E, F2")));
+    connect(m_jumpToFileInNextSplitAction, SIGNAL(triggered()), this, SLOT(openLinkUnderCursorInNextSplit()));
+
     QAction *a = 0;
     a = new QAction(tr("Go to Line Start"), this);
     command = Core::ActionManager::registerAction(a, Constants::GOTO_LINE_START, m_contextId, true);
@@ -459,16 +471,8 @@ void TextEditorActionHandler::createActions()
 
 }
 
-bool TextEditorActionHandler::supportsAction(const Core::Id & /*id */) const
-{
-    return true;
-}
-
 QAction *TextEditorActionHandler::registerNewAction(const Core::Id &id, bool scriptable, const QString &title)
 {
-    if (!supportsAction(id))
-        return 0;
-
     QAction *result = new QAction(title, this);
     Core::ActionManager::registerAction(result, id, m_contextId, scriptable);
     return result;
@@ -508,13 +512,14 @@ void TextEditorActionHandler::updateActions(UpdateMode um)
     m_formatAction->setEnabled((m_optionalActions & Format) && um != ReadOnlyMode);
     m_unCommentSelectionAction->setEnabled((m_optionalActions & UnCommentSelection) && um != ReadOnlyMode);
     m_followSymbolAction->setEnabled(m_optionalActions & FollowSymbolUnderCursor);
+    m_followSymbolInNextSplitAction->setEnabled(m_optionalActions & FollowSymbolUnderCursor);
     m_jumpToFileAction->setEnabled(m_optionalActions & JumpToFileUnderCursor);
+    m_jumpToFileInNextSplitAction->setEnabled(m_optionalActions & JumpToFileUnderCursor);
 
     m_unfoldAllAction->setEnabled((m_optionalActions & UnCollapseAll));
     m_visualizeWhitespaceAction->setChecked(m_currentEditor->displaySettings().m_visualizeWhitespace);
-    if (m_textWrappingAction) {
+    if (m_textWrappingAction)
         m_textWrappingAction->setChecked(m_currentEditor->displaySettings().m_textWrapping);
-    }
 
     updateRedoAction();
     updateUndoAction();
@@ -538,9 +543,8 @@ void TextEditorActionHandler::updateCopyAction()
     const bool hasCopyableText = m_currentEditor && m_currentEditor->textCursor().hasSelection();
     if (m_cutAction)
         m_cutAction->setEnabled(hasCopyableText && updateMode() == WriteMode);
-    if (m_copyAction) {
+    if (m_copyAction)
         m_copyAction->setEnabled(hasCopyableText);
-    }
 }
 
 void TextEditorActionHandler::gotoAction()
@@ -550,7 +554,7 @@ void TextEditorActionHandler::gotoAction()
     QString locatorString = TextEditorPlugin::instance()->lineNumberFilter()->shortcutString();
     locatorString += QLatin1Char(' ');
     const int selectionStart = locatorString.size();
-    locatorString += tr("<line number>");
+    locatorString += tr("<line>:<column>");
     locatorManager->show(locatorString, selectionStart, locatorString.size() - selectionStart);
 }
 
@@ -634,6 +638,7 @@ FUNCTION(insertLineBelow)
 FUNCTION(indent)
 FUNCTION(unindent)
 FUNCTION(openLinkUnderCursor)
+FUNCTION(openLinkUnderCursorInNextSplit)
 
 FUNCTION(gotoLineStart)
 FUNCTION(gotoLineStartWithSelection)
